check_pkg_status: Check if a package is installed with the specified version

View source: R/package_management.R

check_pkg_statusR Documentation

Check if a package is installed with the specified version

Description

Check if a package is installed with the specified version

Usage

check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])

Arguments

pkg

Package name.

version

Package version to check. If NULL, only checks if the package is installed.

lib

The location of the library directories where to install the packages.

Value

TRUE if the package is installed with the specified version, FALSE otherwise.


thisutils documentation built on May 24, 2026, 5:07 p.m.