get_verbose: Get the verbose option

View source: R/log_message.R

get_verboseR Documentation

Get the verbose option

Description

Get the verbose option from the global options or the local argument.

Usage

get_verbose(verbose = NULL)

Arguments

verbose

The verbose option. Default is 'NULL', which means to get the verbose option from the global options.

Value

The verbose option.

Examples

get_verbose()
get_verbose(verbose = FALSE)
get_verbose(verbose = TRUE)

options(log_message.verbose = FALSE)
get_verbose()
get_verbose(verbose = TRUE)

options(log_message.verbose = TRUE)
get_verbose()

options(log_message.verbose = NULL)

thisutils documentation built on May 24, 2026, 5:07 p.m.