is_apple_silicon: Check if the system is running on Apple Silicon

View source: R/utils.R

is_apple_siliconR Documentation

Check if the system is running on Apple Silicon

Description

Check if the system is running on Apple Silicon

Usage

is_apple_silicon()

Value

A logical value.


thisutils documentation built on May 24, 2026, 5:07 p.m.