| parse_inline_expressions | R Documentation |
Parse '' inline expressions and evaluate them in the current environment, while preserving outer formatting markers like '{.val ...}'.
parse_inline_expressions(text, env = parent.frame())
text |
A character string containing inline expressions to parse. |
env |
Environment in which to evaluate expressions. Defaults to the calling environment. |
A character string with expressions evaluated but formatting preserved.
i <- 1
parse_inline_expressions(
"{.val {i}}"
)
x <- 5
y <- 10
parse_inline_expressions(
"{.pkg {x + y}}"
)
name <- "testing"
name <- parse_inline_expressions(
"{.pkg {name}}"
)
name
log_message(name)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.