Check if a package is installed with the specified version
Source:R/package_management.R
check_pkg_status.RdCheck if a package is installed with the specified version
Usage
check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])R/package_management.R
check_pkg_status.RdCheck if a package is installed with the specified version
check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])