View source: R/package_management.R
| check_pkg_status | R Documentation |
Check if a package is installed with the specified version
check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])
pkg |
Package name. |
version |
Package version to check. If |
lib |
The location of the library directories where to install the packages. |
TRUE if the package is installed with the specified version, FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.