Learn R Programming

thisutils (version 0.4.4)

check_pkg_status: Check if a package is installed with the specified version

Description

Check if a package is installed with the specified version

Usage

check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])

Value

TRUE if the package is installed with the specified version, FALSE otherwise.

Arguments

pkg

Package name.

version

Package version to check. If NULL, only checks if the package is installed.

lib

The location of the library directories where to install the packages.