Check if a package is installed with the specified version
check_pkg_status(pkg, version = NULL, lib = .libPaths()[1])TRUE if the package is installed with the specified version, FALSE otherwise.
Package name.
Package version to check. If NULL, only checks if the package is installed.
The location of the library directories where to install the packages.