View source: R/package_management.R
| check_r | R Documentation |
Check and install R packages
check_r(
packages,
lib = .libPaths()[1],
dependencies = TRUE,
force = FALSE,
verbose = TRUE
)
packages |
Package to be installed.
Package source can be CRAN, Bioconductor or Github.
By default, the package name is extracted according to the |
lib |
The location of the library directories where to install the packages. |
dependencies |
Whether to install dependencies of the packages.
Default is |
force |
Whether to force the installation of packages.
Default is |
verbose |
Whether to print the message.
Default is |
Package installation status.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.