Check and install R packages
check_r(
packages,
lib = .libPaths()[1],
dependencies = TRUE,
force = FALSE,
verbose = TRUE
)Package installation status.
Package to be installed.
Package source can be CRAN, Bioconductor or Github.
By default, the package name is extracted according to the packages parameter.
The location of the library directories where to install the packages.
Whether to install dependencies of the packages.
Default is TRUE.
Whether to force the installation of packages.
Default is FALSE.
Whether to print the message.
Default is TRUE.