Rdocumentation
powered by
Learn R Programming
thisutils (version 0.4.4)
is_apple_silicon: Check if the system is running on Apple Silicon
Description
Check if the system is running on Apple Silicon
Usage
is_apple_silicon()
Arguments
Value
A logical value.